==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/entity/client/other/CurrencyRenderer.java <==
package net.db64.homelawnsecurity.entity.client.other;

import net.db64.homelawnsecurity.component.CurrencyComponent;
import net.db64.homelawnsecurity.component.ModDataComponentTypes;
import net.db64.homelawnsecurity.entity.custom.other.CurrencyEntity;
import net.minecraft.class_10442;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_811;
import net.minecraft.class_897;

public class CurrencyRenderer extends class_897<CurrencyEntity, CurrencyRenderState> {
	private final class_10442 itemModelManager;
	//private final boolean lit;

	public CurrencyRenderer(class_5617.class_5618 context, boolean lit) {
		super(context);
		this.itemModelManager = context.method_65566();
		//this.lit = lit;
	}

	public CurrencyRenderer(class_5617.class_5618 context) {
		this(context, false);
	}

	@Override
	protected int getBlockLight(CurrencyEntity entity, class_2338 pos) {
		//return this.lit ? 15 : super.getBlockLight(entity, pos);
		return 15;
	}

	/*@Override
	protected int getSkyLight(CurrencyEntity entity, BlockPos pos) {
		return 15;
	}*/

	public void render(CurrencyRenderState state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int i) {
		matrixStack.method_22903();
		matrixStack.method_22905(state.scale, state.scale, state.scale);
		matrixStack.method_22907(this.field_4676.method_24197());
		/*if (state.model != null) {
			this.itemModelManager
				.renderItem(
					state.stack,
					ModelTransformationMode.GROUND,
					false,
					matrixStack,
					vertexConsumerProvider,
					i,
					OverlayTexture.DEFAULT_UV,
					state.model
				);
		}*/
		state.itemRenderState.method_65604(matrixStack, vertexConsumerProvider, i, class_4608.field_21444);

		matrixStack.method_22909();
		super.method_3936(state, matrixStack, vertexConsumerProvider, i);
	}

	@Override
	public CurrencyRenderState method_55269() {
		return new CurrencyRenderState();
	}

	@Override
	public void updateRenderState(CurrencyEntity entity, CurrencyRenderState state, float f) {
		super.method_62354(entity, state, f);
		class_1799 stack = entity.method_7495();

		this.itemModelManager.method_65595(state.itemRenderState, stack, class_811.field_4318, entity);

		/*state.model = !stack.isEmpty() ? this.itemModelManager.getModel(stack, entity.getWorld(), null, entity.getId()) : null;
		state.stack = stack.copy();*/
		CurrencyComponent currency = stack.method_58694(ModDataComponentTypes.CURRENCY);
		if (currency != null)
			state.scale = class_3532.method_37958(currency.amount(), 5f, 50f, 0.5f, 5f);
		else
			state.scale = 1.0f;

	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/entity/client/other/CurrencyRenderer.java <==
package net.db64.homelawnsecurity.entity.client.other;

import net.db64.homelawnsecurity.component.CurrencyComponent;
import net.db64.homelawnsecurity.component.ModDataComponentTypes;
import net.db64.homelawnsecurity.entity.custom.other.CurrencyEntity;
import net.minecraft.class_10442;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_1799;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4608;
import net.minecraft.class_5617;
import net.minecraft.class_811;
import net.minecraft.class_897;

public class CurrencyRenderer extends class_897<CurrencyEntity, CurrencyRenderState> {
	private final class_10442 itemModelManager;

	/*public CurrencyRenderer(EntityRendererFactory.Context context, boolean lit) {
		super(context);
		this.itemModelManager = context.getItemModelManager();
		this.lit = lit;
	}*/

	public CurrencyRenderer(class_5617.class_5618 context) {
		//this(context, true);
		super(context);
		this.itemModelManager = context.method_65566();
	}

	/*@Override
	protected int getBlockLight(CurrencyEntity entity, BlockPos pos) {
		return this.lit ? 15 : super.getBlockLight(entity, pos);
	}*/

	/*@Override
	protected int getSkyLight(CurrencyEntity entity, BlockPos pos) {
		return 15;
	}*/

	public void render(
		CurrencyRenderState state,
		class_4587 matrixStack,
		class_11659 orderedRenderCommandQueue,
		class_12075 cameraRenderState
	) {
		matrixStack.method_22903();
		matrixStack.method_22905(state.scale, state.scale, state.scale);
		matrixStack.method_22907(cameraRenderState.field_63081);
		/*if (state.model != null) {
			this.itemModelManager
				.renderItem(
					state.stack,
					ModelTransformationMode.GROUND,
					false,
					matrixStack,
					vertexConsumerProvider,
					i,
					OverlayTexture.DEFAULT_UV,
					state.model
				);
		}*/
		state.itemRenderState.method_65604(matrixStack, orderedRenderCommandQueue, state.field_61820, class_4608.field_21444, state.field_61821);

		matrixStack.method_22909();
		super.method_3936(state, matrixStack, orderedRenderCommandQueue, cameraRenderState);
	}

	@Override
	public CurrencyRenderState method_55269() {
		return new CurrencyRenderState();
	}

	@Override
	public void updateRenderState(CurrencyEntity entity, CurrencyRenderState state, float f) {
		super.method_62354(entity, state, f);

		class_1799 stack = entity.method_7495();

		this.itemModelManager.method_65595(state.itemRenderState, stack, class_811.field_4318, entity);

		/*state.model = !stack.isEmpty() ? this.itemModelManager.getModel(stack, entity.getEntityWorld(), null, entity.getId()) : null;
		state.stack = stack.copy();*/
		CurrencyComponent currency = stack.method_58694(ModDataComponentTypes.CURRENCY);
		if (currency != null) {
			state.scale = class_3532.method_37958(currency.amount(), 5f, 50f, 0.5f, 5f);
			state.lit = true;
		}
		else {
			state.scale = 1.0f;
			state.lit = false;
		}

		if (state.lit)
			state.field_61820 = 15728880;
	}
}
